package org.tranql.connector.informix;


import org.tranql.connector.NoExceptionsAreFatalSorter;
import org.tranql.connector.jdbc.AbstractXADataSourceMCF;
import com.informix.jdbcx.IfxXADataSource;


public class XAMCF extends AbstractXADataSourceMCF<IfxXADataSource> {
    
    private String password = "";

    /**
     * Default constructor for an Informix XA DataSource.
     */
    public XAMCF() {
        super(new IfxXADataSource(), new NoExceptionsAreFatalSorter());
    }
 
    public void setServerName(String sn) {
        xaDataSource.setServerName(sn);
    }

    public String getServerName() {
        return xaDataSource.getServerName();
    }
    
    public void setDatabaseName(String dbname) {
        xaDataSource.setDatabaseName(dbname);
    }

    public String getDatabaseName() {
        return xaDataSource.getDatabaseName();
    }

    public void setUserName(String user) {
        xaDataSource.setUser(user);
    }

    public String getUserName() {
        return xaDataSource.getUser();
    }
    
    public void setPassword(String pwd) {
        this.password = pwd;
        xaDataSource.setPassword(pwd);
    }

    public String getPassword() {
        return password;
    }

    public void setPortNumber(Integer pn) {
        xaDataSource.setPortNumber(pn == null ? 0 : pn.intValue());
    }

    public Integer getPortNumber() {
        return new Integer(xaDataSource.getPortNumber());
    }
    
    //The following are Informix specific values.
    
    public void setIfxHost(String ifxHost){
    	if (ifxHost == null || ifxHost.trim().length() == 0) {
            return;
        }
    	xaDataSource.setIfxIFXHOST(ifxHost);
    }
    
    public String getIfxHost(){
    	return xaDataSource.getIfxIFXHOST();
    }
    
    public void setIfxProtocolTrace(Integer ifxPT) {
        xaDataSource.setIfxPROTOCOLTRACE(ifxPT == null ? 0 : ifxPT.intValue());
    }

    public Integer getIfxProtocolTrace() {
        return new Integer(xaDataSource.getIfxPROTOCOLTRACE());
    }
    
    public void setIfxProtocolTraceFile(String ifxPTF) {
        if (ifxPTF == null || ifxPTF.trim().length() == 0) {
            return;
        }
        xaDataSource.setIfxPROTOCOLTRACEFILE(ifxPTF);
    }
   
    public String getIfxProtocolTraceFile() {
        return xaDataSource.getIfxPROTOCOLTRACEFILE();
    }
    
    public void setIfxSQLHostFile(String ifxSF) {
        if (ifxSF == null || ifxSF.trim().length() == 0) {
            return;
        }
        xaDataSource.setIfxSQLH_FILE(ifxSF);
    }
   
    public String getIfxSQLHostFile() {
        return xaDataSource.getIfxSQLH_FILE();
    }
    
    public void setIfxSQLHostType(String ifxST) {
    	if (ifxST == null || ifxST.trim().length() == 0) {
            return;
        }
        xaDataSource.setIfxSQLH_TYPE(ifxST);
    }
    
    public String getIfxSQLHostType() {
        return xaDataSource.getIfxSQLH_TYPE();
    }
    
    /**
     * Equality is defined in terms of the serverName, portNumber and databaseName properties
     */
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof XAMCF) {
        	IfxXADataSource other = ((XAMCF) obj).xaDataSource;
            return equals(xaDataSource.getServerName(), other.getServerName()) &&
                    xaDataSource.getPortNumber() == other.getPortNumber() &&
                    equals(xaDataSource.getDatabaseName(), other.getDatabaseName());
        } else {
            return false;
        }
    }

    private static boolean equals(String a, String b) {
        return a == b || a != null && a.equals(b);
    }

    public int hashCode() {
        return hashCode(xaDataSource.getServerName()) ^ xaDataSource.getPortNumber() ^ hashCode(xaDataSource.getDatabaseName());
    }

    private static int hashCode(String s) {
        return s == null ? 0 : s.hashCode();
    }

    public String toString() {
        return "XAMCF[" + getDatabaseName() + ']';
    }
}
